@@ -1,7 +1,7 @@
 package Pod::Weaver::Role::SectionText::SelfCompletion;
 
-our $DATE = '2014-12-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-08-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use Moose::Role;
@@ -75,7 +75,7 @@ Pod::Weaver::Role::SectionText::SelfCompletion - Provide COMPLETION section text
 
 =head1 VERSION
 
-This document describes version 0.02 of Pod::Weaver::Role::SectionText::SelfCompletion (from Perl distribution Pod-Weaver-Role-SectionText-SelfCompletion), released on 2014-12-13.
+This document describes version 0.03 of Pod::Weaver::Role::SectionText::SelfCompletion (from Perl distribution Pod-Weaver-Role-SectionText-SelfCompletion), released on 2015-08-26.
 
 =head1 DESCRIPTION
 
@@ -100,6 +100,10 @@ Variables:
 
 =back
 
+=head1 SEE ALSO
+
+L<Pod::Weaver::Role::SectionText::HasCompletion>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Role-SectionText-SelfCompletion>.
@@ -122,7 +126,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
